## 融资融券标的（盘前更新）

接口：margin_secs

描述：获取沪深京三大交易所融资融券标的（包括ETF），每天盘前更新

限量：单次最大6000行数据，可根据股票代码、交易日期、交易所代码循环提取

积分：2000积分可调取，5000积分无总量限制，积分越高权限越大，具体参考权限说明

输入参数

| 名称 | 类型 | 必选 | 描述 |
| --- | --- | --- | --- |
| ts_code | str | N | 标的代码 |
| trade_date | str | N | 交易日 |
| exchange | str | N | 交易所（SSE上交所 SZSE深交所 BSE北交所） |
| start_date | str | N | 开始日期 |
| end_date | str | N | 结束日期 |

输出参数

| 名称 | 类型 | 默认显示 | 描述 |
| --- | --- | --- | --- |
| trade_date | str | Y | 交易日期 |
| ts_code | str | Y | 标的代码 |
| name | str | Y | 标的名称 |
| exchange | str | Y | 交易所 |

接口用法

```python
pro = ts.pro_api()

#获取2024年4月17日上交所融资融券标的
df = pro.margin_secs(trade_date='20240417', exchange='SSE')
```

数据样例

```python
trade_date     ts_code      name exchange
0      20240417  510050 .SH    50ETF       SSE
```